@@ -1,10 +1,9 @@
 from vectorio.vector.datasource.ds_reprojected import DataSourceReprojected
 from vectorio.vector.shapefile.shapefile import Shapefile
-from vectorio.vector.shapefile.decorators.shapefile_as_zip import ShapefileAsZip
-from vectorio.vector.shapefile.decorators.shapefile_as_rar import ShapefileAsRar
+from vectorio.vector.shapefile.decorators.shapefile_compressed import ShapefileCompressed
 from vectorio.vector.wkt.wkt import WKT
-from vectorio.vector.geofile.geo_file import GeoFile
 from vectorio.vector.geojson.geojson import Geojson
 from vectorio.vector.composite.vector_composite import VectorComposite
 from vectorio.vector.srs.reprojection import VectorReprojected
 from vectorio.vector.utm.utm_zone import UTMZone
+from vectorio.vector.kml.kml import KML
