@@ -1,5 +1,6 @@
 #!-*-coding:utf-8-*-
 
+from uuid import uuid4
 from osgeo.ogr import DataSource
 
 
@@ -15,7 +16,8 @@ class GDALClonedLayer:
     def ref(self):
         another_layer_defn = self._another_layer.GetLayerDefn()
         out_lyr = self._ds.CreateLayer(
-            'L1', geom_type=self._another_layer.GetGeomType()
+            str(uuid4()), self._another_layer.GetSpatialRef(),
+            geom_type=self._another_layer.GetGeomType()
         )
         for i in range(another_layer_defn.GetFieldCount()):
             out_lyr.CreateField(another_layer_defn.GetFieldDefn(i))
