@@ -1,6 +1,26 @@
 #!-*-coding:utf-8-*-
 
 
+class ImpossibleFindUTMZone(Exception):
+    pass
+
+
+class ImpossibleFindUTMZoneGeometryHasSelfIntersection(ImpossibleFindUTMZone):
+    pass
+
+
+class InvalidOperationForThisDataType(Exception):
+    pass
+
+
+class KMLInvalid(Exception):
+    pass
+
+
+class ShapefilePathWasntPassed(Exception):
+    pass
+
+
 class CharDecodeError(Exception):
     pass
 
